@@ -1,5 +1,5 @@
 --
--- (C) 2019-22 - ntop.org
+-- (C) 2019-24 - ntop.org
 --
 
 local dirs = ntop.getDirs()
@@ -17,8 +17,6 @@ local checks_var = {
    available_modules = nil,
    iface_config = nil, 
    configset = nil,
-   do_benchmark = false,
-   do_print_benchmark = false
 }
 
 local granularity = "5mins" -- See alert_consts.alerts_granularities
@@ -27,3 +25,4 @@ local do_trace = false
 -- #################################################################
 
 checks.interfaceChecks(granularity, checks_var, do_trace)
+checks.hostChecks(granularity, checks_var, do_trace)
