@@ -1,10 +1,9 @@
 --
--- (C) 2013-22 - ntop.org
+-- (C) 2013-24 - ntop.org
 --
 
 local dirs = ntop.getDirs()
 package.path = dirs.installdir .. "/scripts/lua/modules/?.lua;" .. package.path
-package.path = dirs.installdir .. "/scripts/lua/modules/timeseries/?.lua;" .. package.path
 
 local data_retention_utils = require "data_retention_utils"
 
@@ -14,7 +13,7 @@ local interface_id = interface.getId()
 
 -- ########################################################
 
-local data_retention = data_retention_utils.getDataRetentionDays()
+local data_retention = data_retention_utils.getTSAndStatsDataRetentionDays()
 
 -- ###########################################
 
