@@ -1,11 +1,10 @@
 --
--- (C) 2019-22 - ntop.org
+-- (C) 2019-24 - ntop.org
 --
 
 local dirs = ntop.getDirs()
 package.path = dirs.installdir .. "/scripts/lua/modules/?.lua;" .. package.path
 
-local ts_dump = require "ts_min_dump_utils"
 local checks = require "checks"
 
 -- #################################################################
@@ -15,11 +14,11 @@ local checks = require "checks"
 --
 -- The following checks are loaded
 --
--- /var/lib/ntopng/plugins1/callbacks/system/system/ids_ips_log.lua
--- /var/lib/ntopng/plugins1/callbacks/system/system/dropped_alerts.lua
--- /var/lib/ntopng/plugins1/callbacks/system/system/periodic_activity_not_executed.lua
--- /var/lib/ntopng/plugins1/callbacks/system/system/clickhouse_monitor.lua
--- /var/lib/ntopng/plugins1/callbacks/system/system/slow_periodic_activity.lua
+-- /var/lib/ntopng/scripts/callbacks/system/system/ids_ips_log.lua
+-- /var/lib/ntopng/scripts/callbacks/system/system/dropped_alerts.lua
+-- /var/lib/ntopng/scripts/callbacks/system/system/periodic_activity_not_executed.lua
+-- /var/lib/ntopng/scripts/callbacks/system/system/clickhouse_monitor.lua
+-- /var/lib/ntopng/scripts/callbacks/system/system/slow_periodic_activity.lua
 --
 -- #################################################################
 
@@ -29,8 +28,6 @@ local checks_var = {
    system_config = nil,
    available_modules = nil,
    configset = nil,
-   do_benchmark = false,
-   do_print_benchmark = false
 }
 
 local granularity = "min"
