@@ -1,5 +1,5 @@
 --
--- (C) 2013-22 - ntop.org
+-- (C) 2013-24 - ntop.org
 --
 
 local dirs = ntop.getDirs()
@@ -13,9 +13,11 @@ local os_utils = require "os_utils"
 
 sendHTTPContentTypeHeader('text/html')
 
-page_utils.set_active_menu_entry(page_utils.menu_entries.about, { product=info.product })
+page_utils.print_header_and_set_active_menu_entry(page_utils.menu_entries.about, { product=info.product })
 dofile(dirs.installdir .. "/scripts/lua/inc/menu.lua")
 
+local prefs = ntop.getPrefs()
+
 print("<div class='row'>")
 print("<div class='col-12'>")
 
@@ -33,11 +35,24 @@ print("<tr><th>") print(i18n("about.copyright")) print("</th><td colspan=2>"..in
 
 print("<tr><th>"..i18n("about.version").."</th><td colspan=2>"..getNtopngRelease(info, true).."</td></tr>\n")
 if info["pro.systemid"] then
-   print("<tr><th>"..i18n("about.system_id").."</th><td colspan=2>"..info["pro.systemid"].." <A HREF=\"".. ntop.getHttpPrefix() .. "/lua/license.lua\"><i class=\"fas fa-cog\"></i></A></td></tr>\n")
+   print("<tr><th>"..i18n("about.system_id").."</th><td colspan=2>")
+   print("<span><button data-to-copy='".. info["pro.systemid"] .."' class='copy-http-url btn btn-light btn-sm border ms-1' style='cursor: pointer;'><i class='fas fa-copy'></i></button>")
+   print(info["pro.systemid"].." <A HREF=\"".. ntop.getHttpPrefix() .. "/lua/license.lua\"><i class=\"fas fa-cog\"></i></A></td></tr>\n")
+end
+
+print("<tr><th nowrap>"..i18n("about.platform").."</th><td colspan=2>"..info["platform"].." - "..info["bits"] .." bit")
+
+if(info.jemalloc) then print(" (jemalloc)") end
+print("</td></tr>\n")
+
+if(info["hw_model"] ~= nil) then
+    print("<tr><th nowrap>"..i18n("about.hw_model").."</th><td colspan=2>"..info["hw_model"].."</td></tr>\n")
 end
 
-print("<tr><th nowrap>"..i18n("about.platform").."</th><td colspan=2>"..info["platform"].." - "..info["bits"] .." bit</td></tr>\n")
 print("<tr><th nowrap>"..i18n("about.startup_line").."</th><td colspan=2>".. info["product"] .." "..info["command_line"].."</td></tr>\n")
+print("<tr><th nowrap>"..i18n("about.timezone").."</th><td colspan=2>".. info.zoneinfo.."</td></tr>\n")
+print("<tr><th nowrap>"..i18n("about.hosts_hash_size").."</th><td colspan=2>".. prefs.max_num_hosts.."</td></tr>\n")
+print("<tr><th nowrap>"..i18n("about.flows_hash_size").."</th><td colspan=2>".. prefs.max_num_flows.."</td></tr>\n")
 --print("<tr><th colspan=2 align=center>&nbsp;</th></tr>\n")
 
 ndpi_ver = info["version.ndpi"]
@@ -69,7 +84,7 @@ if ts_utils.getDriverName() == "influxdb" then
    print("<tr><th><a href=\"http://www.influxdata.com\" target=\"_blank\">InfluxDB</A></th><td colspan=2><span id='influxdb-info-load' class='spinner-border spinner-border-sm text-primary' role='status'><span class='sr-only'>Loading...</span></span> <span id=\"influxdb-info-text\"></span></td></tr>\n")
    print[[<script>
 $(function() {
-   $.get("]] print(ntop.getHttpPrefix()) print[[/lua/get_influxdb_info.lua", function(info) {
+   $.get("]] print(ntop.getHttpPrefix()) print[[/lua/rest/v2/get/system/health/influxdb.lua", function(info) {
       $("#influxdb-info-load").hide();
       $("#influxdb-info-text").html(info.version + " ");
    }).fail(function() {
@@ -105,8 +120,6 @@ print("</td></tr>\n")
 end
 print("<tr><th><a class='ntopng-external-link' href=\"http://d3js.org\" target=\"_blank\">Data-Driven Documents (d3js) <i class='fas fa-external-link-alt'></i></A></th><td colspan=2>2.9.1 / 3.0</td></tr>\n")
 
-
-
 print("</table>\n")
 
 print("</div>")
