@@ -1,5 +1,5 @@
 --
--- (C) 2017-20 - ntop.org
+-- (C) 2017-24 - ntop.org
 --
 
 local dirs = ntop.getDirs()
@@ -16,18 +16,21 @@ if not recording_utils.isExtractionAvailable() then
   return
 end
 
+local ifid = tonumber(_GET["ifid"] or interface.getId())
 local epoch_begin = tonumber(_GET["epoch_begin"])
 local epoch_end   = tonumber(_GET["epoch_end"])
 
-interface.select(ifname)
+local master_ifid = interface.getMasterInterfaceId(ifid)
 
-local ifstats = interface.getStats()
-
-local window_info = recording_utils.isDataAvailable(ifstats.id, epoch_begin, epoch_end)
+local window_info = recording_utils.isDataAvailable(master_ifid, epoch_begin, epoch_end)
 
 if window_info.epoch_begin and window_info.epoch_end then
-  window_info.epoch_begin_formatted = format_utils.formatEpochShort(window_info.epoch_begin, window_info.epoch_end, window_info.epoch_begin)
-  window_info.epoch_end_formatted = format_utils.formatEpochShort(window_info.epoch_begin, window_info.epoch_end, window_info.epoch_end)
+   window_info.epoch_begin_formatted = format_utils.formatPastEpochShort(window_info.epoch_begin)
+   window_info.epoch_end_formatted = format_utils.formatPastEpochShort(window_info.epoch_end)
+end
+
+if window_info.smart then
+   window_info.info = i18n("traffic_recording.about_to_download_smart")
 end
 
 print(json.encode(window_info))
