@@ -1,5 +1,5 @@
 --
--- (C) 2013-22 - ntop.org
+-- (C) 2013-24 - ntop.org
 --
 
 local dirs = ntop.getDirs()
@@ -13,14 +13,14 @@ local code_editor = require("code_editor")
 
 sendHTTPContentTypeHeader('text/html')
 
-local title = string.gsub(i18n("plugin_browser", {plugin_name = _GET["plugin_path"]}), "/lua/", "")
+local title = string.gsub(i18n("script_browser", {script_name = _GET["script_path"]}), "/lua/", "")
 local referal_script_page = _GET["referal_url"]
 
-page_utils.set_active_menu_entry(page_utils.menu_entries.plugin_browser, {plugin_name = _GET["plugin_path"]})
+page_utils.print_header_and_set_active_menu_entry(page_utils.menu_entries.script_browser, {script_name = _GET["script_path"]})
 
 dofile(dirs.installdir .. "/scripts/lua/inc/menu.lua")
 
 page_utils.print_page_title(title)
-code_editor.editor(_GET["plugin_file_path"], _GET["plugin_path"], referal_script_page)
+code_editor.editor(_GET["script_file_path"], _GET["script_path"], referal_script_page)
 
 dofile(dirs.installdir .. "/scripts/lua/inc/footer.lua")
