@@ -1,5 +1,5 @@
 --
--- (C) 2013-22 - ntop.org
+-- (C) 2013-24 - ntop.org
 --
 
 local dirs = ntop.getDirs()
@@ -10,13 +10,15 @@ require "flow_utils"
 
 local json = require ("dkjson")
 
+local host = {}
+
 local host_info = url2hostinfo(_GET)
 
 if((host_info ~= nil) and (host_info["host"] ~= nil)) then
    interface.select(ifname)
    host = interface.getHostInfo(host_info["host"], host_info["vlan"])
    if(host == nil) then
-      host = "{}"
+      host = {}
    else
       local hostinfo = {host=host["ip"], vlan=host["vlan"]}
 
@@ -25,13 +27,11 @@ if((host_info ~= nil) and (host_info["host"] ~= nil)) then
       if((host["ip"] == host["name"]) and ntop.shouldResolveHost(host["ip"])) then
          -- Actively resolve host if resolution is enabled
          host["name"] = resolveAddress(hostinfo)
+         interface.setHostResolvedName(hostinfo2hostkey(hostinfo), host["name"])
       end
    end
-else
-   host = "{}"
 end
 
-
 sendHTTPContentTypeHeader('text/html')
 --sendHTTPHeader('application/json')
 
