@@ -1,5 +1,5 @@
 --
--- (C) 2013-22 - ntop.org
+-- (C) 2013-24 - ntop.org
 --
 
 local dirs = ntop.getDirs()
@@ -7,7 +7,7 @@ local dirs = ntop.getDirs()
 require "lua_utils"
 local template = require "template_utils"
 local recording_utils = require "recording_utils"
-local ifid = getInterfaceId(ifname)
+local master_ifid = interface.getMasterInterfaceId()
 
 if((not isAdministrator()) or (not recording_utils.isAvailable()) or (not ntop.isEnterpriseM())) then
   return
@@ -23,7 +23,7 @@ if not isEmptyString(_POST["job_action"]) then
   else
     -- no job id
     if _POST["job_action"] == "delete" then
-      recording_utils.deleteAndStopAllJobs(ifid)
+      recording_utils.deleteAndStopAllJobs(master_ifid)
     end
   end
 end
@@ -96,7 +96,7 @@ print[[
 
   $("#extractionjobs").datatable({
          title: "",
-         url: "/lua/traffic_extraction_data.lua",]]
+         url: "/lua/rest/v2/get/pcap/extraction/tasks.lua",]]
 
   -- Sort by column_id if a specific job_id is set to show it in the first table page
   if not isEmptyString(_GET["job_id"]) then
@@ -163,7 +163,7 @@ print[[
 
               for(var file_id=1; file_id<num_job_files; file_id++)
                 links = links + "<li><a href=\\']] print(ntop.getHttpPrefix())
-                print[[/lua/get_extracted_traffic.lua?job_id=" + job_id + "&file_id=" + file_id + "\\'>" + "]]
+                print[[/lua/rest/v2/get/pcap/extraction/data.lua?job_id=" + job_id + "&file_id=" + file_id + "\\'>" + "]]
                 print(i18n("traffic_recording.download_nth_pcap")) print[[".sformat(file_id) + "</a></li>";
 
               links = links + "</ul>";
@@ -172,7 +172,7 @@ print[[
                 "downloadJobFiles('" + links + "')", "]] print(i18n("download")) print[[");
             } else if (num_job_files == 1) {
               datatableAddLinkButtonCallback.bind(row)(actions_td_idx,
-                "]] print(ntop.getHttpPrefix()) print[[/lua/get_extracted_traffic.lua?job_id=" + job_id, "]] print(i18n("download")) print[[");
+                "]] print(ntop.getHttpPrefix()) print[[/lua/rest/v2/get/pcap/extraction/data.lua?job_id=" + job_id, "]] print(i18n("download")) print[[");
             }
 
             if(job_status === "processing") {
