@@ -1,10 +1,14 @@
 --
--- (C) 2013-22 - ntop.org
+-- (C) 2013-24 - ntop.org
 --
 local dirs = ntop.getDirs()
 package.path = dirs.installdir .. "/scripts/lua/modules/?.lua;" .. package.path
 
-require "lua_utils"
+require "lua_utils_generic"
+require "lua_utils_gui"
+require "ntop_utils"
+require "label_utils"
+
 local delete_data_utils = require "delete_data_utils"
 local template_utils = require "template_utils"
 local ui_utils = require "ui_utils"
@@ -35,7 +39,7 @@ local info = ntop.getInfo()
 
 sendHTTPContentTypeHeader('text/html')
 
-page_utils.set_active_menu_entry(page_utils.menu_entries.manage_data)
+page_utils.print_header_and_set_active_menu_entry(page_utils.menu_entries.manage_data)
 
 dofile(dirs.installdir .. "/scripts/lua/inc/menu.lua")
 
@@ -113,13 +117,13 @@ local menu = {
   entries = {
     {
         key = 'export',
-        title = i18n("manage_data.export_tab"),
+        title = i18n("manage_data.export"),
         url = "?page=export",
         hidden = is_system_interface
     },
     {
         key = 'delete',
-        title = i18n("manage_data.delete_tab"),
+        title = i18n("manage_data.delete"),
         url = "?page=delete",
         hidden = not is_admin or is_system_interface,
      },
