@@ -9,168 +9,183 @@ local dirs = ntop.getDirs()
 package.path = dirs.installdir .. "/scripts/lua/modules/alert_keys/?.lua;" .. package.path
 package.path = dirs.installdir .. "/scripts/lua/modules/pools/?.lua;" .. package.path
 
-local alert_severities = require "alert_severities"
-local alert_entities = require "alert_entities"
+require "ntop_utils"
+require "label_utils"
+require "gui_utils"
+require "lua_trace"
+local alert_entities_utils = require "alert_entities_utils"
+local os_utils = require "os_utils"
 local alert_consts = {}
-local os_utils = require("os_utils")
-local lua_path_utils = require "lua_path_utils"
-require("ntop_utils")
 
-if(ntop.isPro()) then
-  package.path = dirs.installdir .. "/pro/scripts/lua/modules/?.lua;" .. package.path
-  -- NOTE: import snmp_utils below to avoid import cycles
+-- ###################################
+
+-- These set of requires just import structs
+local alert_severity_groups = require "alert_severity_groups"
+local alert_granularities = require "alert_granularities"
+local alert_severities = require "alert_severities"
+local alert_categories = require "alert_categories"
+local alert_entities = require "alert_entities"
+local consts = require "consts"
+
+-- ##############################################
+
+alert_consts.categories = alert_categories
+alert_consts.severity_groups = alert_severity_groups
+alert_consts.alert_entities = alert_entities
+alert_consts.alerts_granularities = alert_granularities
+alert_consts.alertEntity = alert_entities_utils.alertEntity
+
+-- ###################################
+
+if (ntop.isPro()) then
+   package.path = dirs.installdir .. "/pro/scripts/lua/modules/?.lua;" .. package.path
+   -- NOTE: import snmp_utils below to avoid import cycles
 end
 
-alert_consts.SEPARATOR = ';'
-
+alert_consts.SEPARATOR = consts.SEPARATOR
 -- NOTE: sqlite can handle about 10-50 alerts/sec
 alert_consts.MAX_NUM_QUEUED_ALERTS_PER_MODULE = 1024 -- should match ALERTS_MANAGER_MAX_ENTITY_ALERTS
-
 alert_consts.MAX_NUM_QUEUED_ALERTS_PER_RECIPIENT = 4096
-
 alert_consts.ALL_ALERT_KEY = 0 -- Special ID to select 'all' alerts
 
 -- ##############################################
 
--- Groups for alert severities to obtain coarser-grained groups of finer-grained alert severities.
--- Used when grouping flow status severities into groups (shown in the UI header bar and flows page drilldown)
---
--- NOTE: keep it in sync with ntop_typedefs.h AlertLevelGroup
---
-alert_consts.severity_groups = {
-  group_none = {
-    severity_group_id = 0,
-    i18n_title = "severity_groups.group_none",
-  },
-  notice_or_lower = {
-    severity_group_id = 1,
-    i18n_title = "severity_groups.group_notice_or_lower",
-  },
-  warning = {
-    severity_group_id = 2,
-    i18n_title = "severity_groups.group_warning",
-  },
-  error = {
-    severity_group_id = 3,
-    i18n_title = "severity_groups.group_error",
-  },
-  critical = {
-    severity_group_id = 4,
-    i18n_title = "severity_groups.group_critical",
-  },
-  emergency = {
-    severity_group_id = 5,
-    i18n_title = "severity_groups.group_emergency",
-},
-}
+local function format_by_id()
+   local f_categories = {}
+   for cat, cat_v in pairs(alert_consts.categories) do
+      if (cat ~= 'other') then
+         f_categories[cat_v.id] = cat_v
+      end
+   end
+   return f_categories
+end
 
--- ##############################################
+alert_consts.categories_id = format_by_id()
 
-alert_consts.alert_entities = alert_entities
-
--- ##############################################
-
--- Keep in sync with C
-alert_consts.alerts_granularities = {
-   ["min"] = {
-      granularity_id = 1,
-      granularity_seconds = 60,
-      i18n_title = "show_alerts.minute",
-      i18n_description = "alerts_thresholds_config.every_minute",
-   },
-   ["5mins"] = {
-      granularity_id = 2,
-      granularity_seconds = 300,
-      i18n_title = "show_alerts.5_min",
-      i18n_description = "alerts_thresholds_config.every_5_minutes",
-   },
-   ["hour"] = {
-      granularity_id = 3,
-      granularity_seconds = 3600,
-      i18n_title = "show_alerts.hourly",
-      i18n_description = "alerts_thresholds_config.hourly",
-   },
-   ["day"] = {
-      granularity_id = 4,
-      granularity_seconds = 86400,
-      i18n_title = "show_alerts.daily",
-      i18n_description = "alerts_thresholds_config.daily",
-   }
-}
+function alert_consts.get_category_by_id(id)
+   if (id == 0) then return alert_consts.categories.other end
+   return alert_consts.categories_id[id]
+end
 
 -- ################################################################################
 
 -- This status is written in Clickhouse/SQLite column `alert_status`
 alert_consts.alert_status = {
    ["historical"] = {
-      -- Alerts written to the database that require attention
+      -- Historical alerts in the db which have not been acknowledged (require attention)
       alert_status_id = 0,
+      i18n_title = "db_search.alert_status.historical",
+      on_db = true
    },
    ["acknowledged"] = {
-      -- Acknowledged (automatically or from the user) alerts written to the database
+      -- Historical alerts in the db which have been acknowledged (automatically or by the user)
       alert_status_id = 1,
+      i18n_title = "db_search.alert_status.acknowledged",
+      on_db = true
    },
    ["engaged"] = {
-      -- Engaged (not actually used in the database as engaged alerts are in memory)
+      -- Engaged alerts not in the persistent database (engaged alerts are in memory only)
       alert_status_id = 2,
+      i18n_title = "db_search.alert_status.engaged",
+      on_db = true
    },
    ["any"] = {
-      -- Not actually used in the database (historical | acknowledged)
+      -- This status is not actually stored in the database (any = historical | acknowledged | engaged)
       alert_status_id = 3,
+      i18n_title = "db_search.alert_status.any",
+      on_db = false
    },
 }
 
 -- ################################################################################
 
+function alert_consts.alertStatusById(status)
+   for key, info in pairs(alert_consts.alert_status) do
+      if info.alert_status_id == status then
+         return info
+      end
+   end
+
+   return nil
+end
+
+-- ################################################################################
+
 alert_consts.ids_rule_maker = {
-  GPL = "GPL",
-  SURICATA = "Suricata",
-  ET = "Emerging Threats",
+   GPL = "GPL",
+   SURICATA = "Suricata",
+   ET = "Emerging Threats",
 }
 
 -- ##############################################
 
+local function getAlertTimeBounds(alert, engaged)
+   local epoch_begin
+   local epoch_end
+   local half_interval = 1800
+   local alert_tstamp = alert.alert_tstamp
+
+   if alert.first_switched and alert.last_switched then
+       -- Flow alert
+       epoch_begin = alert.first_switched - half_interval
+       epoch_end = alert.last_switched + half_interval
+   else
+       local tend = ternary(engaged, os.time(), alert.alert_tstamp_end) or alert_tstamp
+       -- tprint(debug.traceback())
+       half_interval = math.max(half_interval, (tend - alert_tstamp) / 2) -- at least 1 hour interval
+       local middle_time = (tend + alert_tstamp) / 2
+
+       epoch_begin = middle_time - half_interval
+       epoch_end = middle_time + half_interval
+   end
+
+   return math.floor(epoch_begin), math.floor(epoch_end)
+end
+
+-- ##############################################
+
 local alert_entities_id_to_key = {}
 local alert_severities_id_to_key = {}
 local alerts_granularities_id_to_key = {}
 local alerts_granularities_seconds_to_key = {}
 
 local function initMappings()
-  -- alert_entities_id_to_key
-  for key, entity_info in pairs(alert_consts.alert_entities) do
-    alert_entities_id_to_key[entity_info.entity_id] = key
-  end
+   -- alert_entities_id_to_key
+   for key, entity_info in pairs(alert_consts.alert_entities) do
+      alert_entities_id_to_key[entity_info.entity_id] = key
+   end
 
-  -- alert_severities_id_to_key 
-  for key, severity_info in pairs(alert_severities) do
-    if severity_info.severity_id ~= 0 then
-      alert_severities_id_to_key[severity_info.severity_id] = key
-    end
-  end
+   -- alert_severities_id_to_key
+   for key, severity_info in pairs(alert_severities) do
+      if severity_info.severity_id ~= 0 then
+         alert_severities_id_to_key[severity_info.severity_id] = key
+      end
+   end
 
-  -- alerts_granularities_id_to_key 
-  for key, granularity_info in pairs(alert_consts.alerts_granularities) do
-    alerts_granularities_id_to_key[granularity_info.granularity_id] = key
-  end
+   -- alerts_granularities_id_to_key
+   for key, granularity_info in pairs(alert_consts.alerts_granularities) do
+      alerts_granularities_id_to_key[granularity_info.granularity_id] = key
+   end
 
-  -- alerts_granularities_seconds_to_key
-  for key, granularity_info in pairs(alert_consts.alerts_granularities) do
-    alerts_granularities_seconds_to_key[granularity_info.granularity_seconds] = key
-  end
+   -- alerts_granularities_seconds_to_key
+   for key, granularity_info in pairs(alert_consts.alerts_granularities) do
+      alerts_granularities_seconds_to_key[granularity_info.granularity_seconds] = key
+   end
 end
 
 -- ##############################################
 
 function alert_consts.formatHostAlert(ifid, host, vlan)
-   return hostinfo2label({host = host, vlan = vlan}, vlan)
+   return hostinfo2label({ host = host, vlan = vlan }, vlan)
 end
 
 -- ##############################################
 
 function alert_consts.formatAlertEntity(ifid, entity_type, entity_value)
-   require "flow_utils"
+   -- TODO: remove this dependency
+   require "lua_utils_gui"
    local value
-   local epoch_begin, epoch_end = getAlertTimeBounds({alert_tstamp = os.time()})
+   local epoch_begin, epoch_end = getAlertTimeBounds({ alert_tstamp = os.time() })
 
    if entity_type == "host" then
       local host_info = hostkey2hostinfo(entity_value)
@@ -182,18 +197,19 @@ function alert_consts.formatAlertEntity(ifid, entity_type, entity_value)
             value = string.format("%s [%s]", hostinfo2hostkey(host_info), value)
          end
 
-         value = hostinfo2detailshref(host_info, {page = "historical", epoch_begin = epoch_begin, epoch_end = epoch_end}, value, nil, true --[[ check if the link brings to an active page]])
+         value = hostinfo2detailshref(host_info, { page = "historical", epoch_begin = epoch_begin, epoch_end = epoch_end },
+            value, nil, true --[[ check if the link brings to an active page]])
       end
    elseif entity_type == "interface" then
-      value = "<a href='"..ntop.getHttpPrefix().."/lua/if_stats.lua?ifid="..ifid..
-        "&page=historical&epoch_begin="..epoch_begin .."&epoch_end=".. epoch_end ..
-        "'>"..getHumanReadableInterfaceName(getInterfaceName(ifid)).."</a>"
+      value = "<a href='" .. ntop.getHttpPrefix() .. "/lua/if_stats.lua?ifid=" .. ifid ..
+          "&page=historical&epoch_begin=" .. epoch_begin .. "&epoch_end=" .. epoch_end ..
+          "'>" .. getHumanReadableInterfaceName(getInterfaceName(ifid)) .. "</a>"
    elseif entity_type == "network" then
       value = getLocalNetworkAlias(hostkey2hostinfo(entity_value)["host"])
 
-      value = "<a href='"..ntop.getHttpPrefix().."/lua/network_details.lua?network_cidr="..
-        entity_value.."&page=historical&epoch_begin=".. epoch_begin
-         .."&epoch_end=".. epoch_end .."'>" ..value.."</a>"
+      value = "<a href='" .. ntop.getHttpPrefix() .. "/lua/network_details.lua?network_cidr=" ..
+          entity_value .. "&page=historical&epoch_begin=" .. epoch_begin
+          .. "&epoch_end=" .. epoch_end .. "'>" .. value .. "</a>"
    elseif entity_type == "host_pool" then
       local host_pools = require "host_pools"
 
@@ -207,7 +223,7 @@ function alert_consts.formatAlertEntity(ifid, entity_type, entity_value)
    end
 
    -- try to get a localized message
-   local localized = i18n("alert_messages."..entity_type.."_entity", {entity_value=value})
+   local localized = i18n("alert_messages." .. entity_type .. "_entity", { entity_value = value })
 
    if localized ~= nil then
       return localized
@@ -221,9 +237,7 @@ end
 
 function getMacUrl(mac)
    if not mac then
-      tprint("getMacUrl(nil)")
-      tprint(debug.traceback()) 
-      return "" 
+      return ""
    end
    return ntop.getHttpPrefix() .. "/lua/mac_details.lua?host=" .. mac
 end
@@ -231,17 +245,8 @@ end
 -- ##############################################
 
 function getHostUrl(host, vlan_id)
-   return hostinfo2detailsurl({host = host, vlan = vlan_id})
-end
-
--- ##############################################
-
-function getHostPoolUrl(pool_id)
-   if not pool_id then
-      tprint(debug.traceback())
-      return ""
-   end
-   return ntop.getHttpPrefix() .. "/lua/hosts_stats.lua?pool=" .. pool_id
+   require "lua_utils_gui"
+   return hostinfo2detailsurl({ host = host, vlan = vlan_id })
 end
 
 -- ##############################################
@@ -277,7 +282,8 @@ end
 
 function snmpDeviceUrl(snmp_device)
    if showSnmpUrl(snmp_device) then
-      return ntop.getHttpPrefix()..string.format("/lua/pro/enterprise/snmp_device_details.lua?host=%s", snmp_device)
+      return string.format(
+      getHttpHost() .. ntop.getHttpPrefix() .. "/lua/pro/enterprise/snmp_device_details.lua?host=%s", snmp_device)
    end
 
    return "#"
@@ -287,7 +293,9 @@ end
 
 function snmpIfaceUrl(snmp_device, interface_idx)
    if showSnmpUrl(snmp_device) then
-      return ntop.getHttpPrefix()..string.format("/lua/pro/enterprise/snmp_interface_details.lua?host=%s&snmp_port_idx=%d", snmp_device, interface_idx)
+      return string.format(
+      getHttpHost() .. ntop.getHttpPrefix() .. "/lua/pro/enterprise/snmp_interface_details.lua?host=%s&snmp_port_idx=%d",
+         snmp_device, interface_idx)
    end
 
    return "#"
@@ -298,12 +306,12 @@ end
 function alert_consts.getDefinititionDirs()
    local dirs = ntop.getDirs()
 
-   return({
-         -- Path for ntopng-defined builtin alerts
-         os_utils.fixPath(dirs.installdir .. "/scripts/lua/modules/alert_definitions/flow"),
-         os_utils.fixPath(dirs.installdir .. "/scripts/lua/modules/alert_definitions/host"),
-         os_utils.fixPath(dirs.installdir .. "/scripts/lua/modules/alert_definitions/other"),
-          }
+   return ({
+      -- Path for ntopng-defined builtin alerts
+      os_utils.fixPath(dirs.installdir .. "/scripts/lua/modules/alert_definitions/flow"),
+      os_utils.fixPath(dirs.installdir .. "/scripts/lua/modules/alert_definitions/host"),
+      os_utils.fixPath(dirs.installdir .. "/scripts/lua/modules/alert_definitions/other"),
+   }
    )
 end
 
@@ -319,16 +327,12 @@ function alert_consts.alertEntityById(entity_id)
    return alert_consts.alert_entities[alert_entities_id_to_key[entity_id]]
 end
 
-function alert_consts.alertEntity(v)
-   return(alert_consts.alert_entities[v].entity_id)
-end
-
 function alert_consts.alertEntityLabel(v)
-  local entity_id = alert_consts.alertEntityRaw(v)
+   local entity_id = alert_consts.alertEntityRaw(v)
 
-  if(entity_id) then
-    return i18n(alert_consts.alert_entities[entity_id].i18n_label)
-  end
+   if (entity_id) then
+      return i18n(alert_consts.alert_entities[entity_id].i18n_label)
+   end
 end
 
 -- ##############################################
@@ -338,12 +342,13 @@ alert_consts.alert_types = {}
 local alerts_by_id = {} -- All available alerts keyed by entity_id and alert_id
 
 local function loadAlertsDefs()
-   if(false) then
-      if(string.find(debug.traceback(), "second.lua")) then
+   local lua_path_utils = require "lua_path_utils"
+
+   if (false) then
+      if (string.find(debug.traceback(), "second.lua")) then
          traceError(TRACE_WARNING, TRACE_CONSOLE, "second.lua is loading alert_consts.lua. This will slow it down!")
       end
    end
-
    local defs_dirs = alert_consts.getDefinititionDirs()
 
    for _, defs_dir in pairs(defs_dirs) do
@@ -354,7 +359,7 @@ local function loadAlertsDefs()
             local mod_fname = string.sub(fname, 1, string.len(fname) - 4)
             local def_script = require(mod_fname)
 
-            if(def_script == nil) then
+            if (def_script == nil) then
                traceError(TRACE_ERROR, TRACE_CONSOLE, string.format("Error loading alert definition from %s", mod_fname))
                goto next_script
             end
@@ -377,7 +382,8 @@ local function loadAlertsDefs()
             -- Make sure the alert hasn't already been loaded via a dedicated alert_definition .lua file
             if not alert_type then
                -- Can't use the require. Require always returns the same table and this would result in overwritten alert_key and title
-               local def_script = dofile(os_utils.fixPath(string.format("%s/scripts/lua/modules/flow_risk_simple_alert_definition.lua", dirs.installdir)))
+               local def_script = dofile(os_utils.fixPath(string.format(
+               "%s/scripts/lua/modules/flow_risk_simple_alert_definition.lua", dirs.installdir)))
 
                -- Add the mandatory fields according to what arrives from C++
                def_script.meta.alert_key = flow_risk_alert.alert_id
@@ -396,19 +402,21 @@ end
 -- ##############################################
 
 function loadDefinition(def_script, mod_fname, script_path)
-   local required_fields = {"alert_key", "i18n_title", "icon"}
+   local required_fields = { "alert_key", "i18n_title", "icon" }
 
    -- Check the required meta table
-   if(def_script.meta == nil) then
-      traceError(TRACE_ERROR, TRACE_CONSOLE, string.format("Missing required table 'meta' in %s from %s", mod_fname, script_path))
-      return(false)
+   if (def_script.meta == nil) then
+      traceError(TRACE_ERROR, TRACE_CONSOLE,
+         string.format("Missing required table 'meta' in %s from %s", mod_fname, script_path))
+      return (false)
    end
 
    -- Check the required metadata fields
    for _, k in pairs(required_fields) do
-      if(def_script.meta[k] == nil) then
-         traceError(TRACE_ERROR, TRACE_CONSOLE, string.format("Missing required field '%s' in %s from %s", k, mod_fname, script_path))
-         return(false)
+      if (def_script.meta[k] == nil) then
+         traceError(TRACE_ERROR, TRACE_CONSOLE,
+            string.format("Missing required field '%s' in %s from %s", k, mod_fname, script_path))
+         return (false)
       end
    end
 
@@ -425,16 +433,18 @@ function loadDefinition(def_script, mod_fname, script_path)
    local alert_key = def_script.meta.alert_key
 
    if not alert_entity or not alert_key then
-      traceError(TRACE_ERROR, TRACE_CONSOLE, string.format("Invalid alert key specified %s in %s from %s", status, mod_fname, script_path))
-      return(false)
+      traceError(TRACE_ERROR, TRACE_CONSOLE,
+         string.format("Invalid alert key specified %s in %s from %s", status, mod_fname, script_path))
+      return (false)
    end
 
    -- Coherence check: make sure the alert key is not redefined
    local alert_entity_id = alert_entity.entity_id
-  
+
    if alerts_by_id[alert_entity_id] and alerts_by_id[alert_entity_id][alert_key] then
-      traceError(TRACE_ERROR, TRACE_CONSOLE, string.format("Alert key %d redefined, skipping in %s from %s", alert_key, mod_fname, script_path))
-      return(false)
+      traceError(TRACE_ERROR, TRACE_CONSOLE,
+         string.format("Alert key %d redefined, skipping in %s from %s", alert_key, mod_fname, script_path))
+      return (false)
    end
 
    -- Add alert metadata to the script
@@ -458,9 +468,9 @@ function loadDefinition(def_script, mod_fname, script_path)
    end
 
    -- Success
-   return(true)
+   return (true)
 end
- 
+
 -- ##############################################
 
 function alert_consts.alertTypeLabel(alert_id, nohtml, alert_entity_id, nil_on_not_found)
@@ -469,45 +479,150 @@ function alert_consts.alertTypeLabel(alert_id, nohtml, alert_entity_id, nil_on_n
    if alert_key then
       local type_info = alert_consts.alert_types[alert_key]
       -- TODO: .meta is the new format, OR are for compatibility and can be removed when migration is done
-      local title = i18n(type_info.i18n_title or type_info.meta.i18n_title) or type_info.i18n_title or type_info.meta.i18n_title
+      local title = i18n(type_info.i18n_title or type_info.meta.i18n_title) or type_info.i18n_title or
+      type_info.meta.i18n_title
 
       if nohtml then
-        return title
+         return title
       else
-        -- return(string.format('<i class="%s"></i> %s', type_info.icon or type_info.meta.icon, shortenString(title)))
-        return string.format('<i class="%s"></i> %s', type_info.icon or type_info.meta.icon, title)
+         -- return(string.format('<i class="%s"></i> %s', type_info.icon or type_info.meta.icon, shortenString(title)))
+         return string.format('%s', title)
       end
-
    elseif nil_on_not_found then
       return nil
-
    else
-      return(i18n("unknown"))
+      return (i18n("unknown"))
    end
 end
 
 -- ##############################################
 
+function alert_consts.addExtraInfo(alert_id, alert_entity_id, alert_json)
+   local alert_key = alert_consts.getAlertType(alert_id, alert_entity_id)
+   local msg = ""
+
+   if alert_key then
+      local type_info = alert_consts.alert_types[alert_key]
+      if type_info.add_extra_info then
+         msg = type_info.add_extra_info(nil, alert_json)
+      end
+   end
+
+   return msg
+end
+-- ##############################################
+
 -- @brief Given a flow status identified by `status_key`, returns an icon associated to the severity
 -- @param `status info`, A human readable (localized) status info
 -- @param `alerted_severity`, Integer severity of the alert associated to this status
 -- @return The HTML with icon and ALT text, or empty if no icon is available
 function alert_consts.alertTypeIcon(alert_info, alerted_severity, icon_size)
-  local severity = alert_consts.alertSeverityById(alerted_severity)
-  local icon = ''
+   local severity = alert_consts.alertSeverityById(alerted_severity)
+   local icon = ''
 
-  if severity then
-    local severity_icon = (icon_size or 'fa-fw') .. " " .. severity.icon
-    icon = "<i class='"..severity_icon.."' title='"..noHtml(alert_consts.alertTypeLabel(alert_info, true)) .."'></i> "
-  end
+   if severity then
+      local severity_icon = (icon_size or 'fa-fw') .. " " .. severity.icon
+      icon = "<i class='" ..
+      severity_icon .. "' title='" .. noHtml(alert_consts.alertTypeLabel(alert_info, true)) .. "'></i> "
+   end
 
-  return icon
+   return icon
+end
+
+-- ##############################################
+
+function alert_consts.getAlertMitreInfo(v)
+   if (alert_consts.alert_types[v] == nil) then
+      tprint(debug.traceback())
+   end
+
+   local res = nil
+   local key = alert_consts.alert_types[v]
+
+   if key and key.meta then
+      -- TODO AM: attempt at looking inside new implementation `meta`
+      res = key.meta.mitre_values
+   end
+
+   return res
+end
+
+-- ##############################################
+
+function alert_consts.getAlertMitreInfoIDs(v)
+   if (alert_consts.alert_types[v] == nil) then
+      tprint(debug.traceback())
+   end
+
+   local res = nil
+   local key = alert_consts.alert_types[v]
+
+   if key and key.meta then
+      -- TODO AM: attempt at looking inside new implementation `meta`
+      if key.meta.mitre_values then
+         local values = key.meta.mitre_values
+         local tactic = nil
+         local technique = nil
+         local sub_technique = nil
+         if values.mitre_tactic then
+            tactic = values.mitre_tactic.id or nil
+         end
+         if values.mitre_technique then
+            technique = values.mitre_technique.id or nil
+         end
+         if values.mitre_sub_technique then
+            sub_technique = values.mitre_sub_technique.id or nil
+         end
+         res = {
+            mitre_tactic_id = tactic,
+            mitre_technique_id = technique,
+            mitre_sub_technique_id = sub_technique,
+            mitre_id = values.mitre_id
+         }
+      end
+   end
+
+   return res
+end
+
+-- ##############################################
+
+function alert_consts.getAllAlertMitreInfoIDs()
+   local res = {}
+   local key = alert_consts.alert_types[v]
+
+   for key, value in pairs(alert_consts.alert_types) do
+      -- TODO AM: attempt at looking inside new implementation `meta`
+      if value.meta and value.meta.mitre_values then
+         local values = value.meta.mitre_values
+         local tactic = nil
+         local technique = nil
+         local sub_technique = nil
+         if values.mitre_tactic then
+            tactic = values.mitre_tactic.id or nil
+         end
+         if values.mitre_technique then
+            technique = values.mitre_technique.id or nil
+         end
+         if values.mitre_sub_technique then
+            sub_technique = values.mitre_sub_technique.id or nil
+         end
+         res[key] = {
+            mitre_tactic_id = tactic,
+            mitre_technique_id = technique,
+            mitre_sub_technique_id = sub_technique,
+            mitre_id = values.mitre_id
+         }
+      end
+   end
+
+   return res
 end
 
 -- ##############################################
 
 function alert_consts.alertType(v)
-   if(alert_consts.alert_types[v] == nil) then
+   if (alert_consts.alert_types[v] == nil) then
       tprint(debug.traceback())
    end
 
@@ -519,7 +634,7 @@ function alert_consts.alertType(v)
    end
 
    return res
- end
+end
 
 -- ##############################################
 
@@ -547,7 +662,7 @@ function alert_consts.getAlertType(alert_key, alert_entity_id)
    if alerts_by_id[alert_entities.flow.entity_id][alert_key] then
       return alerts_by_id[alert_entities.flow.entity_id][alert_key]
    end
-   
+
    -- Fallback 02: if no alert_entity_id is passed, alert_entity is assumed to be host.
    if alerts_by_id[alert_entities.host.entity_id][alert_key] then
       return alerts_by_id[alert_entities.host.entity_id][alert_key]
@@ -603,21 +718,21 @@ function alert_consts.alertSeverityRaw(severity_id)
    if not alert_severities_id_to_key[severity_id] then
       severity_id = 1 -- falling back to min severity
    end
-   return alert_severities_id_to_key[severity_id] 
+   return alert_severities_id_to_key[severity_id]
 end
 
 -- ################################################################################
 
 function alert_consts.get_printable_severities()
-  local severities = {}
+   local severities = {}
 
-  for name, conf in pairs(alert_severities, "severity_id", asc) do
-    if (conf.severity_id > 2) then
-      severities[name] = conf
-    end
-  end
+   for name, conf in pairs(alert_severities, "severity_id", asc) do
+      if (conf.severity_id > 2) then
+         severities[name] = conf
+      end
+   end
 
-  return severities
+   return severities
 end
 
 -- ################################################################################
@@ -625,18 +740,18 @@ end
 function alert_consts.alertSeverityLabel(score, nohtml, emoji)
    local severity_id = alert_consts.alertSeverityRaw(map_score_to_severity(score))
 
-   if(severity_id) then
+   if (severity_id) then
       local severity_info = alert_severities[severity_id]
       local title = i18n(severity_info.i18n_title) or severity_info.i18n_title
 
-      if(emoji) then
-         title = (severity_info.emoji or "").. " " .. title
+      if (emoji) then
+         title = (severity_info.emoji or "") .. " " .. title
       end
-      
-      if(nohtml) then
-        return(title)
+
+      if (nohtml) then
+         return (title)
       else
-        return(string.format('<span class="badge %s" title="%s">%s</span>', severity_info.label, title, title))
+         return (string.format('<span class="badge %s" title="%s">%s</span>', severity_info.label, title, title))
       end
    end
 
@@ -646,55 +761,74 @@ end
 -- ################################################################################
 
 function alert_consts.alertSeverity(v)
-   return(alert_severities[v].severity_id)
+   return (alert_severities[v].severity_id)
+end
+
+-- ################################################################################
+-- ################################################################################
+
+function alert_consts.getSeverityColorById(severity_id)
+   for _, severity in pairs(alert_severities) do
+      if severity.severity_id == severity_id then
+         return severity.color
+      end
+   end
+   return "#000000" 
+end
+
+function alert_consts.getSeverityLabelById(severity_id)
+   for _, severity in pairs(alert_severities) do
+      if severity.severity_id == severity_id then
+         return i18n(severity.i18n_title)
+      end
+   end
 end
- 
 -- ################################################################################
 
 function alert_consts.alertSeverityById(severity_id)
    local key = alert_consts.alertSeverityRaw(severity_id)
-   if key == nil then 
+   if key == nil then
       return alert_severities.none
    end
-   return(alert_severities[key])
+   return (alert_severities[key])
 end
 
- -- ################################################################################
+-- ################################################################################
 
 -- Rename engine -> granulariy
 local function alertEngineRaw(granularity_id)
    granularity_id = tonumber(granularity_id)
-   return alerts_granularities_id_to_key[granularity_id] 
+   return alerts_granularities_id_to_key[granularity_id]
 end
- 
+
 -- ################################################################################
- 
+
 function alert_consts.alertEngine(v)
-   if(alert_consts.alerts_granularities[v] == nil) then
+   if (alert_consts.alerts_granularities[v] == nil) then
       tprint(debug.traceback())
    end
 
-   return(alert_consts.alerts_granularities[v].granularity_id)
+   return (alert_consts.alerts_granularities[v].granularity_id)
 end
 
 -- ################################################################################
 
 function alert_consts.alertEngineLabel(v)
    local granularity_id = alertEngineRaw(v)
- 
-   if(granularity_id ~= nil) then
-     return(i18n(alert_consts.alerts_granularities[granularity_id].i18n_title))
-   end
- end
 
- -- ################################################################################
+   if (granularity_id ~= nil) then
+      return (i18n(alert_consts.alerts_granularities[granularity_id].i18n_title))
+   end
+end
+
+-- ################################################################################
 
 function alert_consts.granularity2sec(v)
-   if(alert_consts.alerts_granularities[v] == nil) then
+   if (alert_consts.alerts_granularities[v] == nil) then
       tprint(debug.traceback())
    end
 
-  return(alert_consts.alerts_granularities[v].granularity_seconds)
+   return (alert_consts.alerts_granularities[v].granularity_seconds)
 end
 
 -- ################################################################################
@@ -702,7 +836,51 @@ end
 -- See NetworkInterface::checkHostsAlerts()
 function alert_consts.granularity2id(granularity)
    -- TODO replace alertEngine
-   return(alert_consts.alertEngine(granularity))
+   return (alert_consts.alertEngine(granularity))
+end
+
+-- ################################################################################
+
+function alert_consts.formatBehaviorAlert(params, anomalies, stats, id, subtype, name)
+    local debug = false
+    -- Cycle throught the behavior stats
+    for anomaly_type, anomaly_table in pairs(anomalies) do
+        local lower_bound = stats[anomaly_type]["lower_bound"]
+        local upper_bound = stats[anomaly_type]["upper_bound"]
+        local value = stats[anomaly_type]["value"]
+
+        if debug then
+            local msg = string.format("Checking %s behavior for %s (lower bound | value | upper bound): %s | %s | %s",
+                subtype, name, lower_bound, value, upper_bound)
+            traceError(TRACE_NORMAL, TRACE_CONSOLE, msg)
+        end
+
+        if anomaly_table["cut_values"] then
+            value = tonumber(string.format("%.2f", tonumber(value * (anomaly_table["multiplier"] or 1))))
+            lower_bound = tonumber(string.format("%.2f", tonumber(lower_bound * (anomaly_table["multiplier"] or 1))))
+            upper_bound = tonumber(string.format("%.2f", tonumber(upper_bound * (anomaly_table["multiplier"] or 1))))
+        end
+
+        if anomaly_table["formatter"] then
+            value = anomaly_table["formatter"](value)
+            lower_bound = anomaly_table["formatter"](lower_bound)
+            upper_bound = anomaly_table["formatter"](upper_bound)
+        end
+
+        local alert = anomaly_table.alert.new(i18n(subtype .. "_id", {
+            id = name or id
+        }), anomaly_type, value, lower_bound, upper_bound, anomaly_table["entity_id"], id, anomaly_table["extra_params"])
+
+        alert:set_info(params)
+        alert:set_subtype(name)
+
+        -- Trigger an alert if an anomaly is found
+        if anomaly_table["anomaly"] == true then
+            alert:trigger(params.alert_entity, nil, params.cur_alerts)
+        else
+            alert:release(params.alert_entity, nil, params.cur_alerts)
+        end
+    end
 end
 
 -- ################################################################################
@@ -710,18 +888,17 @@ end
 function alert_consts.sec2granularity(seconds)
    seconds = tonumber(seconds)
    local key = alerts_granularities_seconds_to_key[seconds]
-   if not key  then
+   if not key then
       key = alerts_granularities_seconds_to_key[60]
    end
    return key
 end
- 
 -- Load definitions now
 loadAlertsDefs()
 initMappings()
 
-if(trace_script_duration ~= nil) then
-  io.write(debug.getinfo(1,'S').source .." executed in ".. (os.clock()-clock_start)*1000 .. " ms\n")
+if (trace_script_duration ~= nil) then
+   io.write(debug.getinfo(1, 'S').source .. " executed in " .. (os.clock() - clock_start) * 1000 .. " ms\n")
 end
 
 return alert_consts
