@@ -1,5 +1,5 @@
 --
--- (C) 2019-22 - ntop.org
+-- (C) 2019-24 - ntop.org
 --
 
 -- ##############################################
@@ -9,6 +9,8 @@ local flow_alert_keys = require "flow_alert_keys"
 local classes = require "classes"
 -- Make sure to import the Superclass!
 local alert = require "alert"
+-- Import Mitre Att&ck utils
+local mitre = require "mitre_utils"
 
 -- ##############################################
 
@@ -20,6 +22,13 @@ alert_ndpi_dns_invalid_characters.meta = {
    alert_key  = flow_alert_keys.flow_alert_ndpi_invalid_characters,
    i18n_title = "flow_risk.ndpi_invalid_characters",
    icon = "fas fa-fw fa-exclamation",
+
+   -- Mitre Att&ck Matrix values
+   mitre_values = {
+      mitre_tactic = mitre.tactic.credential_access,
+      mitre_technique = mitre.technique.adversary_in_the_middle,
+      mitre_id = "T1557"
+   },
 }
 
 -- ##############################################
@@ -34,7 +43,7 @@ end
 -- #######################################################
 
 function alert_ndpi_dns_invalid_characters.format(ifid, alert, alert_type_params)
-   return ""
+   return i18n("flow_risk.ndpi_invalid_characters_alert_descr")
 end
 
 -- #######################################################
