@@ -1,5 +1,5 @@
 --
--- (C) 2019-22 - ntop.org
+-- (C) 2019-24 - ntop.org
 --
 
 -- ##############################################
@@ -9,6 +9,8 @@ local flow_alert_keys = require "flow_alert_keys"
 local classes = require "classes"
 -- Make sure to import the Superclass!
 local alert = require "alert"
+-- Import Mitre Att&ck utils
+local mitre = require "mitre_utils"
 
 -- ##############################################
 
@@ -18,9 +20,16 @@ local alert_ndpi_http_suspicious_url = classes.class(alert)
 
 alert_ndpi_http_suspicious_url.meta = {
    alert_key  = flow_alert_keys.flow_alert_ndpi_http_suspicious_url,
-   i18n_title = "alerts_dashboard.ndpi_http_suspicious_url_title",
+   i18n_title = "flow_risk.ndpi_http_suspicious_url",
    icon = "fas fa-fw fa-exclamation",
 
+   -- Mitre Att&ck Matrix values
+   mitre_values = {
+      mitre_tactic = mitre.tactic.initial_access,
+      mitre_technique = mitre.technique.drive_by_compr,
+      mitre_id = "T1189"
+   },
+
    has_victim = true,
    has_attacker = true,
 }
@@ -37,7 +46,7 @@ end
 -- #######################################################
 
 function alert_ndpi_http_suspicious_url.format(ifid, alert, alert_type_params)
-   return
+   return i18n('alerts_dashboard.ndpi_http_suspicious_url_descr')
 end
 
 -- #######################################################
