@@ -1,5 +1,5 @@
 --
--- (C) 2019-22 - ntop.org
+-- (C) 2019-24 - ntop.org
 --
 
 -- ##############################################
@@ -10,6 +10,8 @@ local flow_alert_keys = require "flow_alert_keys"
 local classes = require "classes"
 -- Make sure to import the Superclass!
 local alert = require "alert"
+-- Import Mitre Att&ck utils
+local mitre = require "mitre_utils"
 
 -- ##############################################
 
@@ -21,6 +23,14 @@ alert_ndpi_malware_host_contacted.meta = {
   alert_key = flow_alert_keys.flow_alert_ndpi_malware_host_contacted,
   i18n_title = "flow_checks_config.ndpi_malware_host_contacted",
   icon = "fas fa-fw fa-exclamation",
+
+   -- Mitre Att&ck Matrix values
+   mitre_values = {
+      mitre_tactic = mitre.tactic.reconnaissance,
+      mitre_technique = mitre.technique.phishing_info,
+      mitre_sub_technique = mitre.sub_technique.spearphishing_service,
+      mitre_id = "T1598.001"
+   },
 }
 
 -- ##############################################
@@ -34,5 +44,11 @@ end
 
 -- #######################################################
 
+function alert_ndpi_malware_host_contacted.format(ifid, alert, alert_type_params)
+   return i18n("flow_risk.ndpi_malware_host_contacted_alert_descr")
+end
+
+-- #######################################################
+
 return alert_ndpi_malware_host_contacted
 
