@@ -1,5 +1,5 @@
 --
--- (C) 2021-22 - ntop.org
+-- (C) 2021-24 - ntop.org
 --
 local dirs = ntop.getDirs()
 package.path = dirs.installdir .. "/scripts/lua/modules/?.lua;" .. package.path
@@ -302,9 +302,10 @@ function all_alert_store:select_request(filter, select_fields)
     self:add_request_filters()
 
     if ntop.isClickHouseEnabled() and not is_system_interface then
-        -- Add the system interface (-1 = 65535) to show alerts both on the selected
+        -- Add the system interface to show alerts both on the selected
         -- interface and non-interface related.
-        self:add_filter_condition_list('interface_id', 65535, 'number')
+        self:add_filter_condition_list('interface_id', 
+           self:ifid_2_db_ifid(getSystemInterfaceId()), 'number')
     end
 
     -- Add limits and sort criteria
@@ -363,7 +364,8 @@ function all_alert_store:format_record(value, no_html)
     local record = self:format_json_record_common(value, alert_entities.host.entity_id, no_html)
 
     local url = string.format('%s/lua/alert_stats.lua?page=%s&epoch_begin=%u&epoch_end=%u&status=%s',
-        ntop.getHttpPrefix(), alert_consts.alertEntityRaw(value["entity_id"]), _GET["epoch_begin"], _GET["epoch_end"],
+        ntop.getHttpPrefix(), alert_consts.alertEntityRaw(value["entity_id"]),
+        tonumber(_GET["epoch_begin"]), tonumber(_GET["epoch_end"]),
         _GET["status"] or "historical")
 
     local entity = i18n(alert_consts.alertEntityById(value["entity_id"]).i18n_label)
