@@ -1,11 +1,10 @@
 --
--- (C) 2019-22 - ntop.org
+-- (C) 2019-24 - ntop.org
 --
 
 local checks = require("checks")
-local alerts_api = require("alerts_api")
-local alert_consts = require("alert_consts")
 local flow_alert_keys = require "flow_alert_keys"
+local CHECKS_IEC_INVALID_TRANSITION = "ntopng.checks.iec104_invalid_transition_enabled"
 
 -- #################################################################
 
@@ -30,4 +29,16 @@ local script = {
 
 -- #################################################################
 
+function script.onEnable()
+  ntop.setCache(CHECKS_IEC_INVALID_TRANSITION, "1")
+end
+
+-- #################################################################
+
+function script.onDisable()
+  ntop.setCache(CHECKS_IEC_INVALID_TRANSITION, "0")
+end
+
+-- #################################################################
+
 return script
