@@ -1,5 +1,5 @@
 --
--- (C) 2019-22 - ntop.org
+-- (C) 2019-24 - ntop.org
 --
 
 local checks = require("checks")
@@ -7,7 +7,7 @@ local alerts_api = require "alerts_api"
 local alert_consts = require("alert_consts")
 local flow_alert_keys = require "flow_alert_keys"
 
-local UNEXPECTED_PLUGINS_ENABLED_CACHE_KEY = "ntopng.cache.checks.unexpected_plugins_enabled"
+local UNEXPECTED_SCRIPTS_ENABLED_CACHE_KEY = "ntopng.cache.checks.unexpected_scripts_enabled"
 
 -- #################################################################
 
@@ -29,21 +29,16 @@ local script = {
    gui = {
       i18n_title        = "flow_checks.unexpected_dhcp_title",
       i18n_description  = "flow_checks.unexpected_dhcp_description",
-
-      input_builder     = "items_list",
-      item_list_type    = "ip_address",
-      input_title       = "flow_checks.allowed_servers_title",
-      input_description = "flow_checks.allowed_servers_description",
    }
 }
 
 -- #################################################################
 
 function script.onEnable(hook, hook_config)
-   -- Set a flag to indicate to the notifications system that an unexpected plugin
+   -- Set a flag to indicate to the notifications system that an unexpected script
    -- has been enabled
-   if isEmptyString(ntop.getCache(UNEXPECTED_PLUGINS_ENABLED_CACHE_KEY)) then
-      ntop.setCache(UNEXPECTED_PLUGINS_ENABLED_CACHE_KEY, "1")
+   if isEmptyString(ntop.getCache(UNEXPECTED_SCRIPTS_ENABLED_CACHE_KEY)) then
+      ntop.setCache(UNEXPECTED_SCRIPTS_ENABLED_CACHE_KEY, "1")
    end
 end
 
