@@ -1,13 +1,15 @@
 --
--- (C) 2019-22 - ntop.org
+-- (C) 2019-24 - ntop.org
 --
 
 local checks = require("checks")
 local host_alert_keys = require "host_alert_keys"
+local alert_consts = require("alert_consts")
 
 local remote_connection = {
    -- Script category
    category = checks.check_categories.network,
+   severity = alert_consts.get_printable_severities().notice,
 
    default_enabled = false,
    alert_id = host_alert_keys.host_alert_remote_connection,
