@@ -1,5 +1,5 @@
 --
--- (C) 2014-22 - ntop.org
+-- (C) 2014-24 - ntop.org
 --
 
 local dirs = ntop.getDirs()
@@ -773,31 +773,6 @@ end
 
 -- ########################################################
 
-function db_utils.clickhouseDeleteOldPartitions(mysql_retention)
-   local day_aligned_retention = mysql_retention - (mysql_retention % 86400)
-   -- Create a string that identifies the PARTITIONs name of the most recent partition that will be deleted
-   local retention_yyyymmdd = os.date("%Y%m%d", day_aligned_retention)
-
-   -- Deletion is done directly on partitions (Clickhouse database has daily partitions)
-
-   -- Query the partitions that need to be deleted. Convert YYYYMMDD strings into integers so that
-   -- only relevant partitions can be queried and deleted
-   -- The last condition > 999999 prevents old partitions created as YYYMM to be deleted
-   local partitions_q = string.format("SELECT DISTINCT database, table, toUInt32(partition) drop_part FROM system.parts WHERE active AND database='%s' AND drop_part <= %u AND drop_part > 999999", ntop.getPrefs().mysql_dbname or 'ntopng', retention_yyyymmdd)
-   local partitions_res = interface.execSQLQuery(partitions_q)
-
-   if(partitions_res ~= nil) then
-      -- Iterate queried partitions and delete them (nil is returned if there is nothing to delete)
-      for _, partition_info in ipairs(partitions_res) do
-	 local delete_partition_q = string.format("ALTER TABLE %s.%s DROP PARTITION '%s'",
-						  partition_info["database"], partition_info["table"], partition_info["drop_part"])
-	 local delete_partition_res = interface.execSQLQuery(delete_partition_q)
-      end
-   end
-end
-
--- ########################################################
-
 local function _harvest_expired_mysql_flows(ifname, mysql_retention, verbose)
    local dbtables = {"flowsv4", "flowsv6"}
 
@@ -822,5 +797,25 @@ function db_utils.harverstExpiredMySQLFlows(ifname, mysql_retention, verbose)
    end
 end
 
+-- ########################################################
+
+function db_utils.populateExtraTables()
+   for _, info in pairs(extra_tables) do
+      if info.populate_table then
+         info.populate_table()
+      else
+         traceError(TRACE_NORMAL, TRACE_CONSOLE, "Missing populate_table function")
+      end
+   end
+end
+
+-- ########################################################
+
+function db_utils.getExtraTables()
+   return extra_tables
+end
+
+-- ########################################################
+
 return db_utils
 
