@@ -1,5 +1,5 @@
 --
--- (C) 2019-22 - ntop.org
+-- (C) 2019-24 - ntop.org
 --
 -- This file contains flow related constats
 
@@ -97,8 +97,8 @@ flow_consts.flow_fields_description = {
    ["ICMP_IPV4_CODE"] = i18n("flow_fields_description.icmp_ipv4_code"),
    ["POST_NAT_SRC_IPV4_ADDR"] = i18n("flow_fields_description.post_nat_src_ipv4_addr"),
    ["POST_NAT_DST_IPV4_ADDR"] = i18n("flow_fields_description.post_nat_dst_ipv4_addr"),
-   ["POST_NAPT_SRC_TRANSPORT_PORT"] = i18n("flow_fields_description.post_napt_src_transport_port"),
-   ["POST_NAPT_DST_TRANSPORT_PORT"] = i18n("flow_fields_description.post_napt_dst_transport_port"),
+   ["POST_NAT_SRC_TRANSPORT_PORT"] = i18n("flow_fields_description.post_nat_src_transport_port"),
+   ["POST_NAT_DST_TRANSPORT_PORT"] = i18n("flow_fields_description.post_nat_dst_transport_port"),
    ["OBSERVATION_POINT_TYPE"] = i18n("flow_fields_description.observation_point_type"),
    ["OBSERVATION_POINT_ID"] = i18n("flow_fields_description.observation_point_id"),
    ["SELECTOR_ID"] = i18n("flow_fields_description.selector_id"),
@@ -111,6 +111,8 @@ flow_consts.flow_fields_description = {
    ["SELECTOR_NAME"] = i18n("flow_fields_description.selector_name"),
    ["APPLICATION_NAME"] = i18n("flow_fields_description.application_name"),
    ["USER_NAME"] = i18n("flow_fields_description.user_name"),
+   ["WLAN_SSID"] = i18n("flow_fields_description.wlan_ssid"),
+   ["WTP_MAC_ADDRESS"] = i18n("flow_fields_description.wtp_mac_address"),
    ["SRC_FRAGMENTS"] = i18n("flow_fields_description.src_fragments"),
    ["DST_FRAGMENTS"] = i18n("flow_fields_description.dst_fragments"),
    ["CLIENT_NW_LATENCY_MS"] = i18n("flow_fields_description.client_nw_latency_ms"),
@@ -462,7 +464,9 @@ flow_consts.flow_fields_description = {
    ["SIP_REASON_CAUSE"] = i18n("flow_fields_description.sip_reason_cause"),
    ["SIP_C_IP"] = i18n("flow_fields_description.sip_c_ip"),
    ["SIP_CALL_STATE"] = i18n("flow_fields_description.sip_call_state"),
-
+   ["SIP_UAC"] = i18n("flow_fields_description.sip_uac"),
+   ["SIP_UAS"] = i18n("flow_fields_description.sip_uas"),
+   
    -- SMTP Protocol
    ["SMTP_MAIL_FROM"] = i18n("flow_fields_description.smtp_mail_from"),
    ["SMTP_RCPT_TO"] = i18n("flow_fields_description.smtp_rcpt_to"),
@@ -1008,4 +1012,46 @@ flow_consts.mobile_country_code = {
    ["648"] = "Zimbabwe (Republic of)",
 }
 
+-- ################################################################################
+
+-- IMPORTANT: keep it in sync with Flow::ConnectionStates
+
+flow_consts.minor_connection_states = {
+   ["NO_STATE"] = 0,
+   ["S0"] =       1,
+   ["S1"] =       2,
+   ["SF"] =       3,
+   ["REJ"] =      4,
+   ["S2"] =       5,
+   ["S3"] =       6,
+   ["RSTO"] =     7,
+   ["RSTR"] =     8,
+   ["RSTOS0"] =   9,
+   ["RSTRH"] =    10,
+   ["SH"] =       11,
+   ["SHR"] =      12,
+   ["OTH"] =      13
+}
+
+flow_consts.major_connection_states = {
+   ["NO_STATE"]    = 0,
+   ["ATTEMPTED"]   = 1,
+   ["ESTABLISHED"] = 2,
+   ["CLOSED"]      = 3
+}
+
+-- keep in sync with enum DropReason in include/ntop_typedefs.h 
+flow_consts.drop_reason = {
+   [ 1] = { i18n_label = "drop_reason.user_action" },
+   [ 2] = { i18n_label = "drop_reason.probe_verdict" },
+   [ 3] = { i18n_label = "drop_reason.blacklisted_flow" },
+   [ 4] = { i18n_label = "drop_reason.quota_exceeded" },
+   [ 5] = { i18n_label = "drop_reason.drop_cli" },
+   [ 6] = { i18n_label = "drop_reason.drop_srv" },
+   [ 7] = { i18n_label = "drop_reason.cli2srv_shaper" },
+   [ 8] = { i18n_label = "drop_reason.srv2cli_shaper" },
+   [ 9] = { i18n_label = "drop_reason.dev_not_allow_proto_cli" },
+   [10] = { i18n_label = "drop_reason.dev_not_allow_proto_srv" },
+}
+
 return flow_consts
