@@ -1,5 +1,5 @@
 --
--- (C) 2014-22 - ntop.org
+-- (C) 2014-24 - ntop.org
 --
 
 local dirs = ntop.getDirs()
@@ -61,29 +61,31 @@ end
 
 function flow_field_value_maps.map_field_value(ifid, field, value)
    local field_pen, field_id, field_type = flow_field_value_maps.key_to_pen_type_and_value(field)
-   
+
    if field_pen ~= nil and field_id ~= nil then
       -- if pen or type is nil then
       -- it has not been possible to extract pen and type (string field?)
       -- so no mapping can be found for this value
 
       field_id = tonumber(field_id)
-      
-      if(field_pen == NTOP_PEN) then
-	 -- ntop
-	 field_id = field_id + NTOP_BASE_ID
+
+      if (field_pen == NTOP_PEN) then
+         -- ntop
+         field_id = field_id + NTOP_BASE_ID
       end
-      
+
       -- lazy init of the mapping
       init_flow_field_value_map(field_pen)
 
       -- do the actual mapping
       if pen_map[field_pen] then
-	 field, value = pen_map[field_pen].map_field_value(ifid, field_id, value)
+         field, value = pen_map[field_pen].map_field_value(ifid, field_id, value)
       elseif rtemplate[field_id] then
-	 -- If there's no match on pen_map, attempt at decoding using the nProbe rtemplate
-	 -- NOTE: see function getFlowKey in flow_utils.lua
-	 field = rtemplate[tonumber(field_id)]
+         -- If there's no match on pen_map, attempt at decoding using the nProbe rtemplate
+         -- NOTE: see function getFlowKey in flow_utils.lua
+         field = rtemplate[tonumber(field_id)]
+      else
+         field = nil -- Failed, try with description
       end
 
       -- override with static mappings with those received from nProbe on the options topic
