@@ -1,5 +1,5 @@
 --
--- (C) 2013-22 - ntop.org
+-- (C) 2013-24 - ntop.org
 --
 
 require "lua_utils"
@@ -8,7 +8,7 @@ local rest_utils = require("rest_utils")
 
 local new_devices = {}
 
-local redis_key = "ntopng.cache.checks.unexpected_new_device_plugins_enabled"
+local redis_key = "ntopng.cache.checks.unexpected_new_device_scripts_enabled"
 
 -- ################################################################
 
@@ -23,7 +23,7 @@ function new_devices.reset_macs()
         -- Retrieving the list of the addresses already seen
         local seen_devices = ntop.getHashAllCache(seen_devices_hash) or {}
 
-        for key, value in pairs(seen_devices) do
+        for key, _ in pairs(seen_devices) do
             ntop.delHashCache(seen_devices_hash, key)
             ntop.delCache(redis_key .. "." .. key)
         end
