@@ -1,11 +1,15 @@
 --
--- (C) 2014-22 - ntop.org
+-- (C) 2014-24 - ntop.org
 --
 
 local clock_start = os.clock()
 
 local dirs = ntop.getDirs()
-require "lua_utils"
+require "lua_utils_get"
+require "lua_utils_generic"
+require "ntop_utils"
+require "lua_trace"
+
 local json = require("dkjson")
 local os_utils = require("os_utils")
 local scripts_triggers = require "scripts_triggers"
@@ -24,6 +28,7 @@ local is_running_job_pending_key = "ntopng.cache.traffic_recording_job_pending"
 local recording_utils = {}
 
 recording_utils.default_disk_space = 10 * 1024
+recording_utils.default_snaplen = 1536
 
 -- #################################
 
@@ -353,7 +358,7 @@ end
 -- Read information about used disk space for an interface dump
 local function interfaceStorageUsed(ifid)
   local pcap_path = recording_utils.getPcapPath(ifid)
-  return getFolderSize(pcap_path) 
+  return getFolderSize(pcap_path, nil) 
 end
 
 --! @brief Read information about a volume, including storage size and available space
@@ -499,7 +504,7 @@ function recording_utils.createConfig(ifid, params)
     max_file_size = 256,      -- Max file length (MB)
     max_file_duration = 60,   -- Max file duration (sec)
     max_disk_space = recording_utils.default_disk_space, -- Max disk space (MB)
-    snaplen = 1536,           -- Capture length
+    snaplen = recording_utils.default_snaplen, -- Capture length
     writer_core = 0,          -- Writer thread affinity
     reader_core = 1,          -- Reader thread affinity
     indexer_cores = { 2 },    -- Indexer threads affinity
@@ -742,7 +747,7 @@ local function isSmartRecordingEnabled(ifid)
   if cur_provider == "ntopng" then
     return isSmartRecordingEnabledInCache(ifid)
   else
-    return true
+    return false -- TODO detect if smart recording is enabled for the external provider
   end
 end 
 
