@@ -1,5 +1,5 @@
 --
--- (C) 2013-22 - ntop.org
+-- (C) 2013-24 - ntop.org
 --
 
 NTOP_BASE_ID = 57472
@@ -84,6 +84,7 @@ template = {
    ['SAMPLED_PACKET_ID'] = 104,
    ['EXPORTER_IPV4_ADDRESS'] = 130,
    ['EXPORTER_IPV6_ADDRESS'] = 131,
+   ['WLAN_SSID'] = 147,
    ['FLOW_ID'] = 148,
    ['FLOW_START_SEC'] = 150,
    ['FLOW_END_SEC'] = 151,
@@ -92,8 +93,8 @@ template = {
    ['FIREWALL_EVENT'] = 233,
    ['POST_NAT_SRC_IPV4_ADDR'] = 225,
    ['POST_NAT_DST_IPV4_ADDR'] = 226,
-   ['POST_NAPT_SRC_TRANSPORT_PORT'] = 227,
-   ['POST_NAPT_DST_TRANSPORT_PORT'] = 228,
+   ['POST_NAT_SRC_TRANSPORT_PORT'] = 227,
+   ['POST_NAT_DST_TRANSPORT_PORT'] = 228,
    ['OBSERVATION_POINT_TYPE'] = 277,
    ['OBSERVATION_POINT_ID'] = 300,
    ['SELECTOR_ID'] = 302,
@@ -104,6 +105,7 @@ template = {
    ['PACKETS_OBSERVED'] = 318,
    ['PACKETS_SELECTED'] = 319,
    ['SELECTOR_NAME'] = 335,
+   ['WTP_MAC_ADDRESS'] = 367,
    ['SRC_FRAGMENTS'] = NTOP_BASE_ID+80,
    ['DST_FRAGMENTS'] = NTOP_BASE_ID+81,
    ['SRC_TO_DST_MAX_THROUGHPUT'] = NTOP_BASE_ID+82,
@@ -140,7 +142,7 @@ template = {
    ['L7_PROTO_NAME'] = NTOP_BASE_ID+119,
    ['DOWNSTREAM_TUNNEL_ID'] = NTOP_BASE_ID+120,
    ['FLOW_USER_NAME'] = NTOP_BASE_ID+121,
-   ['FLOW_SERVER_NAME'] = NTOP_BASE_ID+122,
+   ['NPROBE_INSTANCE_NAME'] = NTOP_BASE_ID+122,
    ['CLIENT_NW_DELAY_MS'] = NTOP_BASE_ID+123,
    ['SERVER_NW_DELAY_MS'] = NTOP_BASE_ID+124,
    ['APPL_LATENCY_MS'] = NTOP_BASE_ID+125,
@@ -164,6 +166,8 @@ template = {
    ['OUT_DST_OSI_SAP'] = NTOP_BASE_ID+350,
    ['FLOW_VERDICT'] =  NTOP_BASE_ID+522,
    ['L7_RISK_SCORE'] = NTOP_BASE_ID+527,
+   ['L7_INFO'] = NTOP_BASE_ID+539,
+   
    -- SIP
    ['SIP_CALL_ID'] = NTOP_BASE_ID+130,
    ['SIP_CALLING_PARTY'] = NTOP_BASE_ID+131,
@@ -186,7 +190,9 @@ template = {
    ['SIP_REASON_CAUSE'] = NTOP_BASE_ID+148,
    ['SIP_C_IP'] = NTOP_BASE_ID+362,
    ['SIP_CALL_STATE'] = NTOP_BASE_ID+363,
-
+   ["SIP_UAC"] = NTOP_BASE_ID+316,
+   ["SIP_UAS"] = NTOP_BASE_ID+317,
+   
    -- RTP
    ['RTP_FIRST_SEQ'] = NTOP_BASE_ID+150,
    ['RTP_FIRST_TS'] = NTOP_BASE_ID+151,
@@ -266,13 +272,6 @@ template = {
    ['MYSQL_RESPONSE'] = NTOP_BASE_ID+199,
    ['MYSQL_APPL_LATENCY_USEC'] = NTOP_BASE_ID+320,
 
-   -- Oracle
-   ['ORACLE_USERNAME'] = NTOP_BASE_ID+200,
-   ['ORACLE_QUERY'] = NTOP_BASE_ID+201,
-   ['ORACLE_RSP_CODE'] = NTOP_BASE_ID+202,
-   ['ORACLE_RSP_STRING'] = NTOP_BASE_ID+203,
-   ['ORACLE_QUERY_DURATION'] = NTOP_BASE_ID+204,
-
    -- DNS
    ['DNS_QUERY'] = NTOP_BASE_ID+205,
    ['DNS_QUERY_ID'] = NTOP_BASE_ID+206,
@@ -392,6 +391,14 @@ template = {
    ['GTPV0_RAI_CELL_RAC'] = NTOP_BASE_ID+330,
    ['GTPV0_RESPONSE_CAUSE'] = NTOP_BASE_ID+331,
 
+   -- DHCP Protocol
+   ["DHCP_CLIENT_MAC"]    = NTOP_BASE_ID+353,
+   ["DHCP_CLIENT_IP"]     = NTOP_BASE_ID+354,
+   ["DHCP_CLIENT_NAME"]   = NTOP_BASE_ID+355,
+   ["DHCP_REMOTE_ID"]     = NTOP_BASE_ID+423,
+   ["DHCP_SUBSCRIBER_ID"] = NTOP_BASE_ID+424,
+   ["DHCP_MESSAGE_TYPE"]  = NTOP_BASE_ID+429,
+
    -- SSDP
    ['SSDP_HOST'] = NTOP_BASE_ID+462,
    ['SSDP_USN'] = NTOP_BASE_ID+463,
@@ -419,6 +426,12 @@ template = {
    ['DEVICE_NAME']    = NTOP_BASE_ID+552,
 }
 
+--
+-- NOTE
+-- Missing entries are sent by nProbe via
+-- ZMQParserInterface::parseTemplate(()
+---
+
 -- template id to name
 rtemplate = {}
 for key,value in pairs(template) do
