@@ -2,6 +2,9 @@
 -- (C) 2021 - ntop.org
 --
 
+local dirs = ntop.getDirs()
+package.path = dirs.installdir .. "/scripts/lua/modules/timeseries/?.lua;" .. package.path
+
 local ts_utils = require "ts_utils_core"
 local schema
 
@@ -20,6 +23,13 @@ schema:addMetric("bytes_rcvd")
 
 -- ##############################################
 
+schema = ts_utils.newSchema("iface:traffic_ip", {step=1, is_critical_ts=true})
+schema:addTag("ifid")
+schema:addMetric("bytes_ipv4")
+schema:addMetric("bytes_ipv6")
+
+-- ##############################################
+
 schema = ts_utils.newSchema("iface:throughput_bps", {
    step=1,
    is_critical_ts=true,
