@@ -1,31 +1,25 @@
 --
--- (C) 2019-22 - ntop.org
+-- (C) 2019-24 - ntop.org
 --
 local dirs = ntop.getDirs()
 package.path = dirs.installdir .. "/scripts/lua/modules/pools/?.lua;" .. package.path
+package.path = dirs.installdir .. "/scripts/lua/modules/timeseries/schemas/?.lua;" .. package.path
 
-require "lua_utils"
-local graph_utils = require "graph_utils"
-local alert_utils = require "alert_utils"
-local callback_utils = require "callback_utils"
-local ts_utils = require "ts_utils_core"
-local format_utils = require "format_utils"
-local checks = require "checks"
 require "ts_5min"
+require "ntop_utils"
+require "check_redis_prefs"
+local ts_utils = require "ts_utils_core"
+
+local ts_custom
+
+if ntop.exists(dirs.installdir .. "/scripts/lua/modules/timeseries/custom/ts_5min_custom.lua") then
+    package.path = dirs.installdir .. "/scripts/lua/modules/timeseries/custom/?.lua;" .. package.path
+
+    ts_custom = require "ts_5min_custom"
+end
 
 -- Set to true to debug host timeseries points timestamps
 local enable_debug = false
-local enable_behaviour_debug = false
-
-if (ntop.getPref("ntopng.prefs.enable_anomaly_debug") == "1") then
-    enable_behaviour_debug = true
-end
-
-local ts_custom
-if ntop.exists(dirs.installdir .. "/scripts/lua/modules/timeseries/custom/ts_5min_custom.lua") then
-    package.path = dirs.installdir .. "/scripts/lua/modules/timeseries/custom/?.lua;" .. package.path
-    ts_custom = require "ts_5min_custom"
-end
 
 local dirs = ntop.getDirs()
 local ts_dump = {}
@@ -66,6 +60,26 @@ end
 
 -- ########################################################
 
+function ts_dump.blacklist_update(when, verbose)
+    local lists_utils = require("lists_utils")
+    local lists = lists_utils.getCategoryLists()
+
+    for list_name, v in pairs(lists) do
+        local current_hits = v.status.num_hits.total
+        if (current_hits > 0) then
+            list_name = list_name:gsub("%s+", "_") -- replace space with underscore
+            local num_hits = lists_utils.getHitsSinceLastUpdateAndUpdate(list_name, current_hits)
+            ts_utils.append("blacklist_v2:hits", {
+                ifid = getSystemInterfaceId(),
+                blacklist_name = list_name,
+                hits = num_hits
+            }, when)
+        end
+    end
+end
+
+-- ########################################################
+
 function ts_dump.asn_update_rrds(when, ifstats, verbose)
     local asn_info = interface.getASesInfo({
         detailsLevel = "higher"
@@ -114,6 +128,21 @@ function ts_dump.asn_update_rrds(when, ifstats, verbose)
             end
         end
 
+        -- QoE Stats
+        if ntop.isEnterpriseL() then
+            local qoe_list = {}
+            for id, value in pairs(asn_stats.qoe or {}) do
+                local delta = delta_val(interface, "asn_qoe_stats." .. ifstats.id .. "." .. asn .. "." .. id, "5mins", value.num, true)
+                qoe_list[id] = delta
+            end
+    
+            if table.len(qoe_list) > 0 then
+                qoe_list.ifid = ifstats.id
+                qoe_list.asn = asn
+                ts_utils.append("asn:qoe_stats", qoe_list, when)
+            end
+        end
+
         -- Save ASN RTT stats
         if not ifstats.isViewed and not ifstats.isView then
             ts_utils.append("asn:rtt", {
@@ -258,23 +287,6 @@ end
 
 -- ########################################################
 
-function ts_dump.os_update_rrds(when, ifstats, verbose)
-    local os_info = interface.getOSesInfo()
-
-    for _, os_stats in pairs(os_info["os"] or {}) do
-        local OS = os_stats.os
-
-        ts_utils.append("os:traffic", {
-            ifid = ifstats.id,
-            os = OS,
-            bytes_ingress = os_stats["bytes.rcvd"],
-            bytes_egress = os_stats["bytes.sent"]
-        }, when)
-    end
-end
-
--- ########################################################
-
 function ts_dump.vlan_update_rrds(when, ifstats, verbose)
     local vlan_info = interface.getVLANsInfo()
 
@@ -315,150 +327,8 @@ end
 
 -- ########################################################
 
-function ts_dump.sflow_device_update_rrds(when, ifstats, verbose)
-    local flowdevs = interface.getSFlowDevices()
-
-    -- Return in case of view interface, no timeseries for view interface,
-    -- already on the viewed interface.
-    if ifstats.isView then
-        return
-    end
-
-    for interface_id, device_list in pairs(flowdevs or {}) do
-        for key, _value in pairs(device_list, asc) do
-            local ports = interface.getSFlowDeviceInfo(flow_device_ip)
-
-            if (verbose) then
-                print("[" .. __FILE__() .. ":" .. __LINE__() .. "] Processing sFlow probe " .. flow_device_ip .. "\n")
-            end
-
-            for port_idx, port_value in pairs(ports) do
-                if ifstats.has_seen_ebpf_events then
-                    -- This is actualy an event exporter
-                    local dev_ifname = format_utils.formatExporterInterface(port_idx, port_value)
-                    ts_utils.append("evexporter_iface:traffic", {
-                        ifid = ifstats.id,
-                        exporter = flow_device_ip,
-                        ifname = dev_ifname,
-                        bytes_sent = port_value.ifOutOctets,
-                        bytes_rcvd = port_value.ifInOctets
-                    }, when)
-                else
-                    ts_utils.append("sflowdev_port:traffic", {
-                        ifid = ifstats.id,
-                        device = flow_device_ip,
-                        port = port_idx,
-                        bytes_sent = port_value.ifOutOctets,
-                        bytes_rcvd = port_value.ifInOctets
-                    }, when)
-                end
-            end
-        end
-    end
-end
-
--- ########################################################
-
-function ts_dump.flow_device_update_rrds(when, ifstats, verbose)
-    local flowdevs = interface.getFlowDevices() -- Flow, not sFlow here
-
-    -- Return in case of view interface, no timeseries for view interface,
-    -- already on the viewed interface.
-    if ifstats.isView then
-        return
-    end
-
-    for interface, device_list in pairs(flowdevs or {}) do
-        for dev_ip, dev_resolved_name in pairsByValues(device_list, asc) do
-            local ports = interface.getFlowDeviceInfo(flow_device_ip)
-
-            if (verbose) then
-                print("[" .. __FILE__() .. ":" .. __LINE__() .. "] Processing flow probe " .. flow_device_ip .. "\n")
-            end
-
-            for port_idx, port_value in pairs(ports) do
-                -- Traffic
-                ts_utils.append("flowdev_port:traffic", {
-                    ifid = ifstats.id,
-                    device = flow_device_ip,
-                    port = port_idx,
-                    bytes_sent = port_value["bytes.out_bytes"],
-                    bytes_rcvd = port_value["bytes.in_bytes"]
-                }, when)
-
-                -- nDPI
-                for proto_name, proto_stats in pairs(port_value["ndpi"]) do
-                    ts_utils.append("flowdev_port:ndpi", {
-                        ifid = ifstats.id,
-                        device = flow_device_ip,
-                        port = port_idx,
-                        protocol = proto_name,
-                        bytes_sent = proto_stats["bytes.sent"],
-                        bytes_rcvd = proto_stats["bytes.rcvd"]
-                    }, when)
-                end
-            end
-        end
-    end
-end
-
--- ########################################################
-
-function ts_dump.getConfig()
-    local config = {}
-
-    config.host_ts_creation = ntop.getPref("ntopng.prefs.hosts_ts_creation")
-    config.host_ndpi_timeseries_creation = ntop.getPref("ntopng.prefs.host_ndpi_timeseries_creation")
-    config.l2_device_rrd_creation = ntop.getPref("ntopng.prefs.l2_device_rrd_creation")
-    config.l2_device_ndpi_timeseries_creation = ntop.getPref("ntopng.prefs.l2_device_ndpi_timeseries_creation")
-    config.flow_devices_rrd_creation = ntop.getPref("ntopng.prefs.flow_device_port_rrd_creation")
-    config.host_pools_rrd_creation = ntop.getPref("ntopng.prefs.host_pools_rrd_creation")
-    config.snmp_devices_rrd_creation = ntop.getPref("ntopng.prefs.snmp_devices_rrd_creation")
-    config.asn_rrd_creation = ntop.getPref("ntopng.prefs.asn_rrd_creation")
-    config.obs_point_rrd_creation = ntop.getPref("ntopng.prefs.observation_points_rrd_creation")
-    config.country_rrd_creation = ntop.getPref("ntopng.prefs.country_rrd_creation")
-    config.os_rrd_creation = ntop.getPref("ntopng.prefs.os_rrd_creation")
-    config.vlan_rrd_creation = ntop.getPref("ntopng.prefs.vlan_rrd_creation")
-    config.ndpi_flows_timeseries_creation = ntop.getPref("ntopng.prefs.ndpi_flows_rrd_creation")
-    config.interface_ndpi_timeseries_creation = ntop.getPref("ntopng.prefs.interface_ndpi_timeseries_creation")
-
-    -- ########################################################
-    -- Populate some defaults
-    if (tostring(config.flow_devices_rrd_creation) == "1" and ntop.isEnterpriseM() == false) then
-        config.flow_devices_rrd_creation = "0"
-    end
-
-    if (tostring(config.snmp_devices_rrd_creation) == "1" and not (ntop.isEnterpriseM() or ntop.isnEdgeEnterprise())) then
-        config.snmp_devices_rrd_creation = "0"
-    end
-
-    -- Local hosts RRD creation is on, with no nDPI rrd creation
-    if isEmptyString(config.host_ts_creation) then
-        config.host_ts_creation = "light"
-    end
-    if isEmptyString(config.host_ndpi_timeseries_creation) then
-        config.host_ndpi_timeseries_creation = "none"
-    end
-
-    -- Devices RRD creation is OFF, as OFF is the nDPI rrd creation
-    if isEmptyString(config.l2_device_rrd_creation) then
-        config.l2_device_rrd_creation = "0"
-    end
-    if isEmptyString(config.l2_device_ndpi_timeseries_creation) then
-        config.l2_device_ndpi_timeseries_creation = "none"
-    end
-
-    -- Interface RRD creation is on, with per-protocol nDPI, Pref used by Observation Points
-    if isEmptyString(config.interface_ndpi_timeseries_creation) then
-        config.interface_ndpi_timeseries_creation = "per_protocol"
-    end
-
-    return config
-end
-
--- ########################################################
-
 function ts_dump.host_update_stats_rrds(when, hostname, host, ifstats, verbose)
+    local l4_protocol_list = require "l4_protocol_list"
     -- Number of alerted flows
     ts_utils.append("host:alerted_flows", {
         ifid = ifstats.id,
@@ -483,7 +353,7 @@ function ts_dump.host_update_stats_rrds(when, hostname, host, ifstats, verbose)
         flows_as_client = host["host_unreachable_flows.as_client"]
     }, when)
 
-    -- Number of host TCP unidirectional flows  
+    -- Number of host TCP unidirectional flows
     if (host.num_unidirectional_tcp_flows ~= nil) then
         ts_utils.append("host:host_tcp_unidirectional_flows", {
             ifid = ifstats.id,
@@ -537,7 +407,7 @@ function ts_dump.host_update_stats_rrds(when, hostname, host, ifstats, verbose)
         packets_rcvd = host["udp.packets.rcvd"]
     }, when)
 
-    -- Tcp RX Stats 
+    -- Tcp RX Stats
     ts_utils.append("host:tcp_rx_stats", {
         ifid = ifstats.id,
         host = hostname,
@@ -611,48 +481,7 @@ function ts_dump.host_update_stats_rrds(when, hostname, host, ifstats, verbose)
                 upper_bound = (host.contacted_hosts_behaviour.upper_bound or 0)
             }, when)
         end
-        --[[
-        if host["score_behaviour"] then
-            local h = host["score_behaviour"]
 
-            -- Score Behaviour
-            ts_utils.append("host:cli_score_behaviour", {
-                ifid = ifstats.id,
-                host = hostname,
-                value = h["as_client"]["value"],
-                lower_bound = h["as_client"]["lower_bound"],
-                upper_bound = h["as_client"]["upper_bound"]
-            }, when)
-            ts_utils.append("host:srv_score_behaviour", {
-                ifid = ifstats.id,
-                host = hostname,
-                value = h["as_server"]["value"],
-                lower_bound = h["as_server"]["lower_bound"],
-                upper_bound = h["as_server"]["upper_bound"]
-            }, when)
-
-            -- Score Anomalies
-            local cli_anomaly = 0
-            local srv_anomaly = 0
-            if h["as_client"]["anomaly"] == true then
-                cli_anomaly = 1
-            end
-            if h["as_server"]["anomaly"] == true then
-                srv_anomaly = 1
-            end
-
-            ts_utils.append("host:cli_score_anomalies", {
-                ifid = ifstats.id,
-                host = hostname,
-                anomaly = cli_anomaly
-            }, when)
-            ts_utils.append("host:srv_score_anomalies", {
-                ifid = ifstats.id,
-                host = hostname,
-                anomaly = srv_anomaly
-            }, when)
-        end
-]]
         -- Active Flows Behaviour
         if host["active_flows_behaviour"] then
             local h = host["active_flows_behaviour"]
@@ -698,8 +527,8 @@ function ts_dump.host_update_stats_rrds(when, hostname, host, ifstats, verbose)
     end
 
     -- L4 Protocols
-    for id, _ in pairs(l4_keys) do
-        k = l4_keys[id][2]
+    for id, _ in pairs(l4_protocol_list.l4_keys) do
+        local k = l4_protocol_list.l4_keys[id][2]
         if ((host[k .. ".bytes.sent"] ~= nil) and (host[k .. ".bytes.rcvd"] ~= nil)) then
             ts_utils.append("host:l4protos", {
                 ifid = ifstats.id,
@@ -727,6 +556,21 @@ function ts_dump.host_update_stats_rrds(when, hostname, host, ifstats, verbose)
         end
     end
 
+    -- QoE Stats
+    if ntop.isEnterpriseL() then
+        local qoe_list = {}
+        for id, value in pairs(host.qoe or {}) do
+            local delta = delta_val(interface, "host_qoe_stats." .. ifstats.id .. "." .. hostname .. "." .. id, "5mins", value.num, true)
+            qoe_list[id] = delta
+        end
+
+        if table.len(qoe_list) > 0 then
+            qoe_list.ifid = ifstats.id
+            qoe_list.host = hostname
+            ts_utils.append("host:qoe_stats", qoe_list, when)
+        end
+    end
+
     -- UDP breakdown
     ts_utils.append("host:udp_sent_unicast", {
         ifid = ifstats.id,
@@ -842,6 +686,50 @@ end
 
 -- ########################################################
 
+function ts_dump.sflow_device_update_rrds(when, ifstats, verbose)
+    local flowdevs = interface.getSFlowDevices()
+
+    -- Return in case of view interface, no timeseries for view interface,
+    -- already on the viewed interface.
+    if ifstats.isView then
+        return
+    end
+
+    for interface_id, device_list in pairs(flowdevs or {}) do
+       for flow_device_ip, _value in pairs(device_list, asc) do
+            local ports = interface.getSFlowDeviceInfo(flow_device_ip)
+
+            if (verbose) then
+                print("[" .. __FILE__() .. ":" .. __LINE__() .. "] Processing sFlow probe " .. flow_device_ip .. "\n")
+            end
+
+            for port_idx, port_value in pairs(ports) do
+                if ifstats.has_seen_ebpf_events then
+                    -- This is actualy an event exporter
+                    local dev_ifname = format_utils.formatExporterInterface(port_idx, port_value)
+                    ts_utils.append("evexporter_iface:traffic", {
+                        ifid = ifstats.id,
+                        exporter = flow_device_ip,
+                        ifname = dev_ifname,
+                        bytes_sent = port_value.ifOutOctets,
+                        bytes_rcvd = port_value.ifInOctets
+                    }, when)
+                else
+                    ts_utils.append("sflowdev_port:traffic", {
+                        ifid = ifstats.id,
+                        device = flow_device_ip,
+                        port = port_idx,
+                        bytes_sent = port_value.ifOutOctets,
+                        bytes_rcvd = port_value.ifInOctets
+                    }, when)
+                end
+            end
+        end
+    end
+end
+
+-- ########################################################
+
 function ts_dump.host_update_rrd(when, hostname, host, ifstats, verbose, config)
     -- Crunch additional stats for local hosts only
     if config.host_ts_creation ~= "off" then
@@ -868,14 +756,6 @@ function ts_dump.host_update_rrd(when, hostname, host, ifstats, verbose, config)
                 ts_dump.host_update_categories_rrds(when, hostname, host, ifstats, verbose)
             end
         end
-
-        ------------------------
-
-        ----- Custom Stats -----
-
-        ------------------------
-
-        -- tprint(host) -- ### LUCA ADD host stats here
     end
 end
 
@@ -885,6 +765,8 @@ function ts_custom_host_function(when, ifstats, hostname, host_ts)
     -- do nothing
 end
 
+-- ########################################################
+
 local function read_file(path)
     local file = io.open(path, "rb") -- r read mode and b binary mode
     if not file then
@@ -925,10 +807,12 @@ end
 -- See scripts/callbacks/minute/interface/timeseries.lua
 --
 
-function ts_dump.run_5min_dump(_ifname, ifstats, config, when, verbose)
+function ts_dump.run_5min_dump(_ifname, ifstats, when, verbose)
+    local profiling = require "profiling"
+    local callback_utils = require "callback_utils"
+    local config = get5MinTSConfig()
     local num_processed_hosts = 0
     local min_instant = when - (when % 60) - 60
-
     local dump_tstart = os.time()
     local dumped_hosts = {}
 
@@ -1017,20 +901,18 @@ function ts_dump.run_5min_dump(_ifname, ifstats, config, when, verbose)
         ts_dump.country_update_rrds(when, ifstats, verbose)
     end
 
-    -- create RRD for OSes
-    if config.os_rrd_creation == "1" then
-        ts_dump.os_update_rrds(when, ifstats, verbose)
-    end
-
     -- Create RRD for vlans
     if config.vlan_rrd_creation == "1" then
         ts_dump.vlan_update_rrds(when, ifstats, verbose)
     end
 
     -- Create RRDs for flow and sFlow probes
-    if (config.flow_devices_rrd_creation == "1" and ntop.isEnterpriseM()) then
+    if (config.flow_devices_rrd_creation == "1" and ntop.isEnterpriseM() and not highExporterTimeseriesResolution()) then
+        package.path = dirs.installdir .. "/scripts/lua/pro/modules/timeseries/callbacks/?.lua;" .. package.path
+        local exporters_timeseries = require "exporters_timeseries"
+        exporters_timeseries.update_timeseries(when, ifstats, verbose, false)
+        -- Create RRDs for sflow counters
         ts_dump.sflow_device_update_rrds(when, ifstats, verbose)
-        ts_dump.flow_device_update_rrds(when, ifstats, verbose)
     end
 
     -- Save Host Pools stats every 5 minutes
@@ -1038,7 +920,7 @@ function ts_dump.run_5min_dump(_ifname, ifstats, config, when, verbose)
         local host_pools = require "host_pools"
         local host_pools_instance = host_pools:create()
 
-        host_pools_instance:updateRRDs(ifstats.id, true --[[ also dump nDPI data ]] , verbose)
+        host_pools_instance:updateRRDs(ifstats.id, true --[[ also dump nDPI data ]] , verbose, when)
     end
 end
 
