@@ -1,5 +1,5 @@
 --
--- (C) 2017-22 - ntop.org
+-- (C) 2017-24 - ntop.org
 --
 
 local dirs = ntop.getDirs()
@@ -14,9 +14,9 @@ sendHTTPContentTypeHeader('text/html')
 
 
 if not ntop.isnEdge() then
-   page_utils.set_active_menu_entry(page_utils.menu_entries.host_pools)
+   page_utils.print_header_and_set_active_menu_entry(page_utils.menu_entries.host_pools)
 else
-   page_utils.set_active_menu_entry(page_utils.menu_entries.users)
+   page_utils.print_header_and_set_active_menu_entry(page_utils.menu_entries.users)
 end
 
 dofile(dirs.installdir .. "/scripts/lua/inc/menu.lua")
