@@ -1,5 +1,5 @@
 --
--- (C) 2013-22 - ntop.org
+-- (C) 2013-24 - ntop.org
 --
 
 local dirs = ntop.getDirs()
@@ -33,7 +33,7 @@ end
 interface.select(ifid)
 
 -- Add filters
-host_alert_store:add_request_filters()
+host_alert_store:add_request_filters(true)
 
 host_alert_store:acknowledge(_GET["label"])
 
