@@ -8,12 +8,9 @@ package.path = dirs.installdir .. "/scripts/lua/modules/import_export/?.lua;" ..
 
 require "lua_utils"
 
-local plugins_utils = require("plugins_utils")
 local infrastructure_import_export = require("infrastructure_import_export")
-local json = require "dkjson"
 local rest_utils = require "rest_utils"
 local import_export_rest_utils = require "import_export_rest_utils"
-local auth = require "auth"
 
 --
 -- Reset infrastructure Dashboard configuration
@@ -27,7 +24,7 @@ if not isAdministratorOrPrintErr() then
     return
 end
 
-if not ntop.isEnterpriseL() then
+if not ntop.isEnterpriseL() and not ntop.isnEdgeEnterprise() then
    rest_utils.answer(rest_utils.consts.err.not_granted)
    return
 end
